@@ -7,8 +7,8 @@ from loguru import logger
 from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret
 
-package_dir = os.path.dirname(os.path.abspath(__file__))
-envpath = os.path.join(package_dir,'../../.env')
+PACKAGE_DIR = os.path.dirname(os.path.abspath(__file__))
+envpath = os.path.join(PACKAGE_DIR, '../../.env')
 
 config = Config(envpath)
 
