@@ -2,7 +2,7 @@ import os
 import sys
 from typing import List
 from tqatest.app.core.errors import PredictException, ModelLoadException
-from tqatest.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
+from tqatest.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID, PACKAGE_DIR
 from loguru import logger
 from tqatest.ml.libs import annhub
 
@@ -13,19 +13,19 @@ class MachineLearningModel(object):
         self.load()
 
     def load(self):
-        # if MODEL_PATH.endswith("/"):
-        #     path = f"{MODEL_PATH}{MODEL_NAME}"
-        # else:
-        #     path = f"{MODEL_PATH}/{MODEL_NAME}"
+        if MODEL_PATH.endswith("/"):
+            path = f"{MODEL_PATH}{MODEL_NAME}"
+        else:
+            path = f"{MODEL_PATH}/{MODEL_NAME}"
 
-        # path = os.path.abspath(os.path.join(os.getcwd(), path))
+        path = os.path.abspath(os.path.join(PACKAGE_DIR, path))
 
-        # if not os.path.exists(path):
-        #     message = f"Machine learning model at {path} not exists!"
-        #     logger.error(message)
-        #     raise FileNotFoundError(message)
-        package_dir = os.path.dirname(os.path.abspath(__file__))
-        path = os.path.join(package_dir,'../../ml/model/TrainedModel_c++.ann')
+        if not os.path.exists(path):
+            message = f"Machine learning model at {path} not exists!"
+            logger.error(message)
+            raise FileNotFoundError(message)
+        # package_dir = os.path.dirname(os.path.abspath(__file__))
+        # path = os.path.join(package_dir,'../../ml/model/TrainedModel_c++.ann')
 
         self.load_model(path)
     
